window.Gleam.initSearch([{"doc":"glow_auth","title":"glow_auth","content":"# Glow Auth -- for OAuth2\n\n[![Package Version](https://img.shields.io/hexpm/v/glow_auth)](https://hex.pm/packages/glow_auth)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glow_auth/)\n[![Test](https://github.com/adz/glow_auth/actions/workflows/test.yml/badge.svg)](https://github.com/adz/glow_auth/actions/workflows/test.yml)\n\nGlow Auth is a gleam OAuth 2.0 helper library.\n\nSee [RFC 6749 - The OAuth 2.0 Authorization Framework](https://datatracker.ietf.org/doc/html/rfc6749)\nfor all the gory details... however, relevant parts have been adapted\ninto the docs here.\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add glow_auth\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/glow_auth&gt;.\n\nThe OAuth 2.0 authorization framework enables a third-party\napplication to obtain limited access to an HTTP service, either on\nbehalf of a resource owner (e.g. a user) by orchestrating an approval\ninteraction between the resource owner and the HTTP service, or by\nallowing the third-party application to obtain access on its own behalf.\n\n\n# Grant Types\n\nAccess is granted by way of one of the following grant types:\n\n * Authorization Code, \n * Implicit (not supported),\n * Resource Owner Password Credentials (not supported), \n * Client Credentials,\n * Extension Grants (not supported).\n\nEach grant type differs in details, but will result in an &#39;access token&#39;\nwhen successful. See below for specifics.\n\nOnce granted an &#39;access token&#39;, it is typically included as a header\nin your requests to access the HTTP service.\n\n * Use [glow_auth#authorization_header](./glow_auth.html#authorization_header)\n   to embed the access token as a header in your request.\n\nIt&#39;s pretty common for these to have an expiry and support a refresh flow.\n\n * Use [glow_auth.token_request#refresh](./glow_auth/token_request.html#refresh)\n   to refresh a token.\n\n## Authorization Code\n\nNote that the &#39;client&#39; would typically be your gleam app running as a\nweb server:\n\n     +----------+          Client Identifier      +---------------+\n     |         -+----(A)-- &amp; Redirection URI ----&gt;|               |\n     | Browser  |                                 | Authorization |\n     |         -+----(B)-- User authenticates ---&gt;|     Server    |\n     |          |                                 |               |\n     |         -+----(C)-- Authorization Code ---&lt;|               |\n     +-|----|---+                                 +---------------+\n       |    |                                         ^      v\n      (A)  (C)                                        |      |\n       |    |                                         |      |\n       ^    v                                         |      |\n     +---------+                                      |      |\n     |         |&gt;---(D)-- Authorization Code ---------&#39;      |\n     |  Client |          &amp; Redirection URI                  |\n     |         |                                             |\n     |         |&lt;---(E)----- Access Token -------------------&#39;\n     +---------+       (w/ Optional Refresh Token)\n\nMore details at [RFC 6749: Section 4.1]( https://datatracker.ietf.org/doc/html/rfc6749#section-4.1 )\n\nIn this grant type, the users browser is directed to an authorization\nserver (A) to authenticate (B) and establish whether the user wants to\ngrant or deny access. When successful, the authorization server\nredirects the user back with an &#39;authorization code&#39; in the uri (C).\n\n * Use [glow_auth/authorize_uri](./glow_auth/authorize_uri.html) to build up the\n   authorization uri to redirect to. \n\nAfter receiving the &#39;authorization code&#39; you must use it to request an\n&#39;access token&#39; from the authorization server.\n\n * Use [glow_auth/token_request#authorize_code](./glow_auth/token_request.html#authorize_code)\n   to request an access token.\n   * Note: must include the redirection URI used to obtain the &#39;authorization code&#39;.\n * Use [glow_auth/access_token#decoder](./glow_auth/access_token.html#decoder)\n   to decode an access token response to an [Access Token](./glow_auth/access_token.html#AccessToken).\n\n## Implicit\n\nThe implicit grant is a simplified authorization code flow optimized\nfor clients implemented in a browser using a scripting language such\nas JavaScript.  In the implicit flow, instead of issuing the client\nan authorization code, the client is issued an access token directly.\n\nNot supported.\n\n\n## Resource Owner Password Credentials\n\nThe resource owner password credentials (i.e., username and password)\ncan be used directly as an authorization grant to obtain an access\ntoken.  The credentials should only be used when there is a high\ndegree of trust between the resource owner and the client (e.g., the\nclient is part of the device operating system or a highly privileged\napplication), and when other authorization grant types are not\navailable (such as an authorization code).\n\nNot supported (yet).\n\n\n## Client Credentials\n\n     +---------+                                  +---------------+\n     |         |                                  |               |\n     |         |&gt;--(A)- Client Authentication ---&gt;| Authorization |\n     | Client  |                                  |     Server    |\n     |         |&lt;--(B)---- Access Token ---------&lt;|               |\n     |         |                                  |               |\n     +---------+                                  +---------------+\n\n   (A)  The client authenticates with the authorization server and\n        requests an access token from the token endpoint.\n\n   (B)  The authorization server authenticates the client, and if valid,\n        issues an access token.\n\nMore details at [RFC 6749: Section 4.4](https://datatracker.ietf.org/doc/html/rfc6749#section-4.4)\n\n * Use [glow_auth/token_request#client_credentials](./glow_auth/token_request.html#client_credentials)\n   to do the token request.\n * Use [glow_auth/access_token#decoder](./glow_auth/access_token.html#decoder)\n   to decode an access token response to an [Access Token](./glow_auth/access_token.html#AccessToken).\n\n# Refreshing\n\nIssuing a refresh token is optional at the discretion of the\nauthorization server.  _If_ the authorization server issues a refresh\ntoken, it is included when issuing an access token, typically also with\nseconds till expiry.\n\n * Use [glow_auth.token_request#refresh](./glow_auth/token_request.html#refresh)\n   to refresh a token.\n\n\n# Concurrency Considerations\n\n 1. When receiving a code in an AuthCode flow redirect, be aware that if an\n    auth code is used more than once, it MUST be denied, and all tokens\n    previously issued based on it\n 1. When refreshing a token, typically the old access tokens are revoked.\n","url":"index.html"},{"doc":"glow_auth","title":"Client","content":"pub type Client(body) {\n  Client(id: String, secret: String, site: Uri)\n}\n A client credentials with an id and secret.\n\n Use the &#39;site&#39; to set a base Uri, perhaps useful when\n token and auth uri&#39;s are relative.\nClient(id: String, secret: String, site: Uri)\n\n\nSynonyms:\nglow_auth.Client\nglow_auth Client","url":"glow_auth.html#Client"},{"doc":"glow_auth","title":"authorization_header","content":"pub fn authorization_header(\n  r: Request(a),\n  token: String,\n) -&gt; Request(a)\n Prepend an access token as an authorization header bearer token\nSynonyms:\nglow_auth.authorization_header\nglow_auth authorization_header","url":"glow_auth.html#authorization_header"},{"doc":"glow_auth","title":"glow_auth","content":"","url":"glow_auth.html"},{"doc":"glow_auth/access_token","title":"AccessToken","content":"pub type AccessToken {\n  AccessToken(\n    access_token: String,\n    token_type: String,\n    refresh_token: Option(String),\n    expires_at: Option(Int),\n    scope: Option(String),\n  )\n}\n Represents a token returned from an oauth2 provider\n\n Note: expires_in is seconds till expiry from time of issue\n which is converted to expires_at by adding to time_now().\nAccessToken(\n  access_token: String,\n  token_type: String,\n  refresh_token: Option(String),\n  expires_at: Option(Int),\n  scope: Option(String),\n)\n\n\nSynonyms:\nglow_auth/access_token.AccessToken\nglow_auth/access_token AccessToken","url":"glow_auth/access_token.html#AccessToken"},{"doc":"glow_auth/access_token","title":"decode_token_from_response","content":"pub fn decode_token_from_response(\n  response: String,\n) -&gt; Result(AccessToken, DecodeError)\n\nSynonyms:\nglow_auth/access_token.decode_token_from_response\nglow_auth/access_token decode_token_from_response","url":"glow_auth/access_token.html#decode_token_from_response"},{"doc":"glow_auth/access_token","title":"decoder","content":"pub fn decoder() -&gt; fn(Dynamic) -&gt;\n  Result(AccessToken, List(DecodeError))\n Decode an access token\n TODO: Any other params are possible, so should be returned as a map.\nSynonyms:\nglow_auth/access_token.decoder\nglow_auth/access_token decoder","url":"glow_auth/access_token.html#decoder"},{"doc":"glow_auth/access_token","title":"from_decoded_response","content":"pub fn from_decoded_response(\n  access_token: String,\n  token_type: String,\n  refresh_token: Option(String),\n  expires_in: Option(Int),\n  scope: Option(String),\n) -&gt; AccessToken\n\nSynonyms:\nglow_auth/access_token.from_decoded_response\nglow_auth/access_token from_decoded_response","url":"glow_auth/access_token.html#from_decoded_response"},{"doc":"glow_auth/access_token","title":"from_now","content":"pub fn from_now(seconds: Int) -&gt; Int\n\nSynonyms:\nglow_auth/access_token.from_now\nglow_auth/access_token from_now","url":"glow_auth/access_token.html#from_now"},{"doc":"glow_auth/access_token","title":"has_an_expiry","content":"pub fn has_an_expiry(access_token: AccessToken) -&gt; Bool\n\nSynonyms:\nglow_auth/access_token.has_an_expiry\nglow_auth/access_token has_an_expiry","url":"glow_auth/access_token.html#has_an_expiry"},{"doc":"glow_auth/access_token","title":"is_expired","content":"pub fn is_expired(access_token: AccessToken) -&gt; Bool\n\nSynonyms:\nglow_auth/access_token.is_expired\nglow_auth/access_token is_expired","url":"glow_auth/access_token.html#is_expired"},{"doc":"glow_auth/access_token","title":"is_expired_at","content":"pub fn is_expired_at(access_token: AccessToken, at: Int) -&gt; Bool\n\nSynonyms:\nglow_auth/access_token.is_expired_at\nglow_auth/access_token is_expired_at","url":"glow_auth/access_token.html#is_expired_at"},{"doc":"glow_auth/access_token","title":"new","content":"pub fn new(token: String) -&gt; AccessToken\n  Returns a new `AccessToken` given the access token `string`.\nSynonyms:\nglow_auth/access_token.new\nglow_auth/access_token new","url":"glow_auth/access_token.html#new"},{"doc":"glow_auth/access_token","title":"normalize_token_type","content":"pub fn normalize_token_type(token_type: String) -&gt; String\n\nSynonyms:\nglow_auth/access_token.normalize_token_type\nglow_auth/access_token normalize_token_type","url":"glow_auth/access_token.html#normalize_token_type"},{"doc":"glow_auth/access_token","title":"time_now","content":"pub fn time_now() -&gt; Int\n\nSynonyms:\nglow_auth/access_token.time_now\nglow_auth/access_token time_now","url":"glow_auth/access_token.html#time_now"},{"doc":"glow_auth/access_token","title":"glow_auth/access_token","content":" An access token is just a string, but it typically expires.\n\n Depending on the type of grant, it may be refreshable via a separate\n refresh token, or by directly requesting a new access token.\n\n ...the intention is to generate this from the response given when\n sending a token request.","url":"glow_auth/access_token.html"},{"doc":"glow_auth/uri/uri_builder","title":"UriAppendage","content":"pub type UriAppendage {\n  RelativePath(String)\n  FullPath(String)\n  FullUri(Uri)\n}\n Uri Appendage defines a few handy ways of appending to an existing Uri.\n\n See `append` for how you can use this.\nRelativePath(String)\n Represent a relative path, expected to be directly appended to existing Uri.\n\nFullPath(String)\n Represent a full path, expected to completely replace an existing Uri.\n\nFullUri(Uri)\n Represent a full uri, expected to completely replace the Uri.\n\nSynonyms:\nglow_auth/uri/uri_builder.UriAppendage\nglow_auth/uri/uri_builder UriAppendage","url":"glow_auth/uri/uri_builder.html#UriAppendage"},{"doc":"glow_auth/uri/uri_builder","title":"append","content":"pub fn append(to uri: Uri, with appendage: UriAppendage) -&gt; Uri\n Append to an existing Uri in explicit ways.\n\n ## Examples\n\n \n &gt; import gleam/uri.Uri\n &gt;\n &gt; my_uri = Uri(Some(&quot;https&quot;), None, Some(&quot;example.com&quot;), Some(443), &quot;/the/path&quot;, None, None)\n &gt; RelativePath(&quot;to/the/thing&quot;) |&gt; uri_append(to: my_uri)\n \n Uri(...my_uri, path: &quot;/the/path/to/the/thing&quot;)\n\n &gt; FullPath(&quot;to/the/thing&quot;) |&gt; uri_append(to: my_uri)\n \n Uri(...my_uri, path: &quot;to/the/thing&quot;)\n\n &gt; another_uri = Uri(Some(&quot;http&quot;), None, Some(&quot;localhost&quot;), Some(80), &quot;/over/here&quot;, None, None)\n &gt; FullUri(another_uri) |&gt; uri_append(to: my_uri)\n\n another_uri // &lt;- it is the same as identity(another_uri)\n\nSynonyms:\nglow_auth/uri/uri_builder.append\nglow_auth/uri/uri_builder append","url":"glow_auth/uri/uri_builder.html#append"},{"doc":"glow_auth/uri/uri_builder","title":"glow_auth/uri/uri_builder","content":" Uri Builder helps to append relative paths to a Uri, but\n with the capacity to fully replace the path\n or full Uri via an explicit UriAppendage type.\n","url":"glow_auth/uri/uri_builder.html"},{"doc":"glow_auth/authorize_uri","title":"AuthUriSpec","content":"pub type AuthUriSpec(body) {\n  AuthUriSpec(\n    client: Client(body),\n    authorize_uri: UriAppendage,\n    redirect_uri: Uri,\n    scope: Option(String),\n    state: Option(String),\n  )\n}\n Represents the details needed to build an authorization Uri.\n\n Use [build](#build), [set_scope](#set_scope), [set_state](#set_state) to build\n up one of these, then [to_code_authorization_uri](#to_code_authorization_uri)\n or [to_implicit_authorization_uri](#to_implicit_authorization_uri)\n to convert to a Uri.\nAuthUriSpec(\n  client: Client(body),\n  authorize_uri: UriAppendage,\n  redirect_uri: Uri,\n  scope: Option(String),\n  state: Option(String),\n)\n\n\nSynonyms:\nglow_auth/authorize_uri.AuthUriSpec\nglow_auth/authorize_uri AuthUriSpec","url":"glow_auth/authorize_uri.html#AuthUriSpec"},{"doc":"glow_auth/authorize_uri","title":"build","content":"pub fn build(\n  client: Client(a),\n  authorize_uri: UriAppendage,\n  redirect_uri: Uri,\n) -&gt; AuthUriSpec(a)\n Build a AuthUriSpec for an AuthCode authorize_uri.\n\n Important things to note:\n  * The exact redirect_uri specified in this uri must also be provided\n    when requesting an access token.\nSynonyms:\nglow_auth/authorize_uri.build\nglow_auth/authorize_uri build","url":"glow_auth/authorize_uri.html#build"},{"doc":"glow_auth/authorize_uri","title":"set_redirect_uri","content":"pub fn set_redirect_uri(\n  spec: AuthUriSpec(a),\n  redirect_uri: Uri,\n) -&gt; AuthUriSpec(a)\n Set the Redirect uri in the AuthUriSpec\nSynonyms:\nglow_auth/authorize_uri.set_redirect_uri\nglow_auth/authorize_uri set_redirect_uri","url":"glow_auth/authorize_uri.html#set_redirect_uri"},{"doc":"glow_auth/authorize_uri","title":"set_scope","content":"pub fn set_scope(\n  spec: AuthUriSpec(a),\n  scope: String,\n) -&gt; AuthUriSpec(a)\n Set the scope in the AuthUriSpec\nSynonyms:\nglow_auth/authorize_uri.set_scope\nglow_auth/authorize_uri set_scope","url":"glow_auth/authorize_uri.html#set_scope"},{"doc":"glow_auth/authorize_uri","title":"set_state","content":"pub fn set_state(\n  spec: AuthUriSpec(a),\n  state: String,\n) -&gt; AuthUriSpec(a)\n Set the state in the AuthUriSpec\n\n This can be useful as it will be included on the redirect back.\nSynonyms:\nglow_auth/authorize_uri.set_state\nglow_auth/authorize_uri set_state","url":"glow_auth/authorize_uri.html#set_state"},{"doc":"glow_auth/authorize_uri","title":"to_code_authorization_uri","content":"pub fn to_code_authorization_uri(spec: AuthUriSpec(a)) -&gt; Uri\n Convert an AuthUriSpec to an Authorization Uri for `code` flow.\nSynonyms:\nglow_auth/authorize_uri.to_code_authorization_uri\nglow_auth/authorize_uri to_code_authorization_uri","url":"glow_auth/authorize_uri.html#to_code_authorization_uri"},{"doc":"glow_auth/authorize_uri","title":"to_implicit_authorization_uri","content":"pub fn to_implicit_authorization_uri(spec: AuthUriSpec(a)) -&gt; Uri\n Convert an AuthUriSpec to an Authorization Uri for `implicit` flow.\nSynonyms:\nglow_auth/authorize_uri.to_implicit_authorization_uri\nglow_auth/authorize_uri to_implicit_authorization_uri","url":"glow_auth/authorize_uri.html#to_implicit_authorization_uri"},{"doc":"glow_auth/authorize_uri","title":"glow_auth/authorize_uri","content":" A builder to generate an Authorization Uri.\n\n In Authorization Code flow, they&#39;ll be redirected with a &quot;code&quot; in the uri,\n which is short lived (10 minutes expiry recommended) that must be exchanged\n for an Access Token separately.\n\n In Implicit flow, they&#39;ll be redirected with a access token details\n directly encoded in the uri.\n\n In both cases, you can send over a `state` which will be sent back to you\n on the redirect.\n\n Failure is represented by the fields:\n  * error - set to one of:\n     * invalid_request\n     * unauthorized_client\n     * access_denied\n     * unsupported_response_type \n     * invalid_scope \n     * server_error \n     * temporarily_unavailable\n  * error_description - optional human readable\n  * error_uri - link to a &#39;more info&#39; page\n  * state - the exact value previously specified in the authorization Uri\n\n The exception is if there is a problem with the Redirect Uri, like not set,\n or not registered in the Authorization provider, in which case the redirect\n back will just not occur.\n\n Some requirements:\n  * MAY have query component\n  * MUST NOT have fragment component\n  * MUST use TLS\n  * MUST support GET method\n  * MAY support POST as well\n  * Params without value MUST be same as omission\n  * No repeat params\n  * MUST include response_type, typically json\n\n Note that when redirected, the response:\n  * MUST include the &quot;code&quot; for AuthCode, or the &quot;token&quot; if Implicit\n  * MUST return error if response_type is missing or misunderstood\n  * MAY have query component\n  * MUST NOT have fragment component\n  * SHOULD use TLS for &quot;code&quot; or &quot;token&quot;\n  * Typically are registered in advance of usage\n  * Receiving response SHOULD NOT do js, but redirect again without exposing creds","url":"glow_auth/authorize_uri.html"},{"doc":"glow_auth/content_type","title":"content_type_from_request","content":"pub fn content_type_from_request(request: Request(a)) -&gt; String\n\nSynonyms:\nglow_auth/content_type.content_type_from_request\nglow_auth/content_type content_type_from_request","url":"glow_auth/content_type.html#content_type_from_request"},{"doc":"glow_auth/content_type","title":"glow_auth/content_type","content":" WIP -- not used, but the idea is to help out in decode of access token...","url":"glow_auth/content_type.html"},{"doc":"glow_auth/uri/params","title":"Params","content":"pub type Params {\n  Params(map: Dict(String, String))\n}\n\nParams(map: Dict(String, String))\n\n\nSynonyms:\nglow_auth/uri/params.Params\nglow_auth/uri/params Params","url":"glow_auth/uri/params.html#Params"},{"doc":"glow_auth/uri/params","title":"from_map","content":"pub fn from_map(map: Dict(String, String)) -&gt; Params\n\nSynonyms:\nglow_auth/uri/params.from_map\nglow_auth/uri/params from_map","url":"glow_auth/uri/params.html#from_map"},{"doc":"glow_auth/uri/params","title":"new","content":"pub fn new() -&gt; Params\n\nSynonyms:\nglow_auth/uri/params.new\nglow_auth/uri/params new","url":"glow_auth/uri/params.html#new"},{"doc":"glow_auth/uri/params","title":"put","content":"pub fn put(params: Params, key: String, value: String) -&gt; Params\n\nSynonyms:\nglow_auth/uri/params.put\nglow_auth/uri/params put","url":"glow_auth/uri/params.html#put"},{"doc":"glow_auth/uri/params","title":"to_list","content":"pub fn to_list(params: Params) -&gt; List(#(String, String))\n\nSynonyms:\nglow_auth/uri/params.to_list\nglow_auth/uri/params to_list","url":"glow_auth/uri/params.html#to_list"},{"doc":"glow_auth/uri/params","title":"to_query","content":"pub fn to_query(params: Params) -&gt; String\n\nSynonyms:\nglow_auth/uri/params.to_query\nglow_auth/uri/params to_query","url":"glow_auth/uri/params.html#to_query"},{"doc":"glow_auth/uri/params","title":"glow_auth/uri/params","content":"","url":"glow_auth/uri/params.html"},{"doc":"glow_auth/token_request_builder","title":"TokenRequestBuilder","content":"pub type TokenRequestBuilder(body) {\n  TokenRequestBuilder(request: Request(body), params: Params)\n}\n\nTokenRequestBuilder(request: Request(body), params: Params)\n\n\nSynonyms:\nglow_auth/token_request_builder.TokenRequestBuilder\nglow_auth/token_request_builder TokenRequestBuilder","url":"glow_auth/token_request_builder.html#TokenRequestBuilder"},{"doc":"glow_auth/token_request_builder","title":"from_request","content":"pub fn from_request(\n  request: Request(a),\n) -&gt; TokenRequestBuilder(a)\n Constructor: from request\nSynonyms:\nglow_auth/token_request_builder.from_request\nglow_auth/token_request_builder from_request","url":"glow_auth/token_request_builder.html#from_request"},{"doc":"glow_auth/token_request_builder","title":"from_uri","content":"pub fn from_uri(uri: Uri) -&gt; TokenRequestBuilder(String)\n Convert a Uri to a TokenRequestBuilder\n\n Note that Request requires a schema and host, but uri doesn&#39;t, so here:\n  * If you don&#39;t specify a scheme, `https` is assumed\n  * If you don&#39;t specify a host, `localhost` is assumed\nSynonyms:\nglow_auth/token_request_builder.from_uri\nglow_auth/token_request_builder from_uri","url":"glow_auth/token_request_builder.html#from_uri"},{"doc":"glow_auth/token_request_builder","title":"map_request","content":"pub fn map_request(\n  rb: TokenRequestBuilder(a),\n  f: fn(Request(a)) -&gt; Request(b),\n) -&gt; TokenRequestBuilder(b)\n Map `f` over the request.\nSynonyms:\nglow_auth/token_request_builder.map_request\nglow_auth/token_request_builder map_request","url":"glow_auth/token_request_builder.html#map_request"},{"doc":"glow_auth/token_request_builder","title":"put_param","content":"pub fn put_param(\n  rb: TokenRequestBuilder(a),\n  key: String,\n  value: String,\n) -&gt; TokenRequestBuilder(a)\n Put one param in\nSynonyms:\nglow_auth/token_request_builder.put_param\nglow_auth/token_request_builder put_param","url":"glow_auth/token_request_builder.html#put_param"},{"doc":"glow_auth/token_request_builder","title":"set_params","content":"pub fn set_params(\n  rb: TokenRequestBuilder(a),\n  params: Params,\n) -&gt; TokenRequestBuilder(a)\n Set all the Params\nSynonyms:\nglow_auth/token_request_builder.set_params\nglow_auth/token_request_builder set_params","url":"glow_auth/token_request_builder.html#set_params"},{"doc":"glow_auth/token_request_builder","title":"to_token_request","content":"pub fn to_token_request(\n  rb: TokenRequestBuilder(a),\n) -&gt; Request(String)\n Access Tokens are requested by form encoded values in the body, while the\n server returns json.\n\n Some flows allow a GET request where the request query-encodes into the uri.\n\n This function handles both depending on the request.method.\nSynonyms:\nglow_auth/token_request_builder.to_token_request\nglow_auth/token_request_builder to_token_request","url":"glow_auth/token_request_builder.html#to_token_request"},{"doc":"glow_auth/token_request_builder","title":"glow_auth/token_request_builder","content":" Request Builder to help building up token requests.\n\n It&#39;s basically just a [Request](https://hexdocs.pm/gleam_http/gleam/http/request.html#Request)\n with additional Params to form-encode in the body, or (less commonly) use\n as the query part of the Uri.\n\n Token request requirements:\n  *  MAY have query component\n  *  MUST NOT have fragment component\n  *  MUST use TLS\n  *  MUST be &quot;POST&quot;\n  *  Params without value MUST be same as omission\n  *  No repeat params\n  *  `scope` space-delimited case insensitive strings defined by auth server\n    *  MAY full or partly ignore\n    *  If different, MUST include `scope` in response\n    *  A default must be defined","url":"glow_auth/token_request_builder.html"},{"doc":"glow_auth/token_request","title":"AuthScheme","content":"pub type AuthScheme {\n  AuthHeader\n  RequestBody\n}\n Confidential clients or other clients issued client credentials can\n authenticate with the authorization server by means of auth header or \n the request body.\nAuthHeader\n Clients in possession of a client password MAY use the HTTP Basic\n authentication scheme as defined in [RFC2617] to authenticate with\n the authorization server.  The client identifier is encoded using the\n &quot;application/x-www-form-urlencoded&quot; encoding.\n\nRequestBody\n Alternatively, the authorization server MAY support including the\n client credentials in the request-body (client_id and client_secret).\n\nSynonyms:\nglow_auth/token_request.AuthScheme\nglow_auth/token_request AuthScheme","url":"glow_auth/token_request.html#AuthScheme"},{"doc":"glow_auth/token_request","title":"Scope","content":"pub type Scope {\n  ScopeList(List(String))\n  ScopeString(String)\n  DefaultScope\n}\n The [Access Token Scope](https://datatracker.ietf.org/doc/html/rfc6749#section-3.3)\n is a list of unordered, space-deliminated, case-sensitive strings.\nScopeList(List(String))\n Respresents the access token scope as a list of individual scope values that can \n later be joined into a space-delimited string.\n\nScopeString(String)\n Represents the access token scope as a string of one or more space-deliminated scopes.\n Useful for a single scope or when the scopes have been pre-joined.\n\nDefaultScope\n Represents the omission of an access token scope.\n Useful when the authorization server will fall back to a default scope when the scope\n is not present in the body.\n\nSynonyms:\nglow_auth/token_request.Scope\nglow_auth/token_request Scope","url":"glow_auth/token_request.html#Scope"},{"doc":"glow_auth/token_request","title":"add_auth","content":"pub fn add_auth(\n  rb: TokenRequestBuilder(a),\n  client: Client(b),\n  auth_scheme: AuthScheme,\n) -&gt; TokenRequestBuilder(a)\n Add auth by means of either AuthHeader or RequestBody \nSynonyms:\nglow_auth/token_request.add_auth\nglow_auth/token_request add_auth","url":"glow_auth/token_request.html#add_auth"},{"doc":"glow_auth/token_request","title":"add_auth_to_body","content":"pub fn add_auth_to_body(\n  client: Client(a),\n  rb: TokenRequestBuilder(b),\n) -&gt; TokenRequestBuilder(b)\n Add the client id and secret params to the token TokenRequestBuilder\n\n Use this when posting the auth in the request body.\nSynonyms:\nglow_auth/token_request.add_auth_to_body\nglow_auth/token_request add_auth_to_body","url":"glow_auth/token_request.html#add_auth_to_body"},{"doc":"glow_auth/token_request","title":"add_basic_auth_header","content":"pub fn add_basic_auth_header(\n  request: Request(a),\n  auth_token: String,\n) -&gt; Request(a)\n Add base64 encoded `authorization` header for basic auth.\n\n Use this when sending the auth in the request headers.\nSynonyms:\nglow_auth/token_request.add_basic_auth_header\nglow_auth/token_request add_basic_auth_header","url":"glow_auth/token_request.html#add_basic_auth_header"},{"doc":"glow_auth/token_request","title":"add_client_basic_auth_header","content":"pub fn add_client_basic_auth_header(\n  client: Client(a),\n  request: Request(b),\n) -&gt; Request(b)\n\nSynonyms:\nglow_auth/token_request.add_client_basic_auth_header\nglow_auth/token_request add_client_basic_auth_header","url":"glow_auth/token_request.html#add_client_basic_auth_header"},{"doc":"glow_auth/token_request","title":"add_scope","content":"pub fn add_scope(\n  rb: TokenRequestBuilder(a),\n  scope: Scope,\n) -&gt; TokenRequestBuilder(a)\n Add a scope to the builder if not a DefaultScope.\nSynonyms:\nglow_auth/token_request.add_scope\nglow_auth/token_request add_scope","url":"glow_auth/token_request.html#add_scope"},{"doc":"glow_auth/token_request","title":"authorization_code","content":"pub fn authorization_code(\n  client: Client(a),\n  token_uri: UriAppendage,\n  code: String,\n  redirect_uri: Uri,\n) -&gt; Request(String)\n Build a token request using a code in \n [Authorization Code grant](https://datatracker.ietf.org/doc/html/rfc6749#section-4.1.3).\n\n Note that the redirect_uri must be identical to usage in the\n [Authorization Uri](./authorize_uri.html).\nSynonyms:\nglow_auth/token_request.authorization_code\nglow_auth/token_request authorization_code","url":"glow_auth/token_request.html#authorization_code"},{"doc":"glow_auth/token_request","title":"client_credentials","content":"pub fn client_credentials(\n  client: Client(a),\n  token_uri: UriAppendage,\n  auth_scheme: AuthScheme,\n  scope: Scope,\n) -&gt; Request(String)\n Build a token request using the client id/secret and optionally a access token scope in\n [Client Credentials grant](https://datatracker.ietf.org/doc/html/rfc6749#section-4.4.2)\nSynonyms:\nglow_auth/token_request.client_credentials\nglow_auth/token_request client_credentials","url":"glow_auth/token_request.html#client_credentials"},{"doc":"glow_auth/token_request","title":"refresh","content":"pub fn refresh(\n  client: Client(a),\n  token_uri: UriAppendage,\n  refresh_token: String,\n) -&gt; Request(String)\n Build a token request using a \n [Refresh token](https://datatracker.ietf.org/doc/html/rfc6749#section-6)\nSynonyms:\nglow_auth/token_request.refresh\nglow_auth/token_request refresh","url":"glow_auth/token_request.html#refresh"},{"doc":"glow_auth/token_request","title":"glow_auth/token_request","content":" Token Request functions.","url":"glow_auth/token_request.html"}]);